"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const router_1 = __importDefault(require("./router"));
const operations_1 = require("./operations");
const middleware_1 = require("./middleware");
const createMiddleware = ({ file, locale = 'en', options = {}, }) => {
    if (!fs_1.default.existsSync(file)) {
        throw new Error('File with the openapi docs does not exist');
    }
    const router = router_1.default();
    const operations = operations_1.createOperations({ file, locale, options });
    router.use('/{0,}', (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
        res.locals.operation = yield operations.match(req);
        next();
    }));
    router.use(middleware_1.isAuthenticated, middleware_1.validateHeaders, middleware_1.validatePath, middleware_1.validateQuery, middleware_1.validateBody);
    router.use((req, res, next) => {
        return res.locals.operation ? res.locals.operation.generateResponse(req, res) : next();
    });
    router.use((req, res) => {
        res.status(404).send({ message: 'Not found' });
    });
    router.use((err, req, res) => {
        res.status(500).send({ message: 'Something broke!' });
    });
    return router;
};
exports.default = createMiddleware;
//# sourceMappingURL=index.js.map