"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const chokidar_1 = __importDefault(require("chokidar"));
const swagger_parser_1 = __importDefault(require("swagger-parser"));
const lodash_1 = require("lodash");
const utils_1 = require("../utils");
const operation_1 = require("./operation");
class Operations {
    constructor({ file, locale, options, }) {
        this.operations = null;
        this.file = file;
        this.locale = locale;
        this.watch();
        this.generator = utils_1.createGenerator(locale, options);
    }
    reset() {
        this.operations = null;
    }
    watch() {
        const watcher = chokidar_1.default.watch(path_1.default.dirname(this.file));
        watcher.on('all', () => this.reset());
    }
    compile() {
        return __awaiter(this, void 0, void 0, function* () {
            const api = yield swagger_parser_1.default.dereference(this.file);
            this.operations = lodash_1.toPairs(api.paths).reduce((result, [pathName, pathOperations]) => [
                ...result,
                ...this.compileFromPath(pathName, pathOperations, lodash_1.get(api, 'components.securitySchemes')),
            ], []);
        });
    }
    /* eslint-disable class-methods-use-this */
    compileFromPath(pathName, pathOperations, securitySchemes) {
        return lodash_1.toPairs(pathOperations).map(([method, operation]) => operation_1.createOperation({
            method,
            path: pathName,
            operation,
            securitySchemes,
            generator: this.generator,
        }));
    }
    /* eslint-enable class-methods-use-this */
    match(req) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.operations) {
                yield this.compile();
            }
            const { method, path: pathname } = req;
            return ((this.operations &&
                this.operations.find(({ method: operationMethod, pathRegexp }) => pathRegexp.exec(pathname) && method.toUpperCase() === operationMethod.toUpperCase())) ||
                null);
        });
    }
}
exports.Operations = Operations;
exports.createOperations = ({ file, locale, options, }) => new Operations({ file, locale, options });
//# sourceMappingURL=operations.js.map